@@ -30,6 +30,7 @@
 
 #include "mainwindow.h"
 
+#define KANAGRAM_VERSION "1.2"
 Q_LOGGING_CATEGORY(KANAGRAM, "org.kde.kanagram")
 
 int main(int argc, char **argv)
@@ -41,7 +42,7 @@ int main(int argc, char **argv)
     migrator.migrate();
 
     QApplication::setApplicationName("kanagram");
-    QApplication::setApplicationVersion("1.0");
+    QApplication::setApplicationVersion(KANAGRAM_VERSION);
     QApplication::setOrganizationDomain("kde.org");
     KLocalizedString::setApplicationDomain("kanagram");
     QApplication::setApplicationDisplayName(i18n("kanagram"));
@@ -49,7 +50,7 @@ int main(int argc, char **argv)
 
     KAboutData about(I18N_NOOP("kanagram"),
                      i18n("Kanagram"),
-                     I18N_NOOP("1.0"),
+                     I18N_NOOP(KANAGRAM_VERSION),
                      i18n("An anagram game"),
                      KAboutLicense::GPL,
                      i18n("© 2005 Joshua Keel\n© 2005 Danny Allen\n© 2007 Jeremy Whiting\n© 2014 Debjit Mondal"));
@@ -67,6 +68,8 @@ int main(int argc, char **argv)
     about.addCredit(i18n("Jure Repinc"), i18n("Slovenian Data Files"), "jlp@holodeck1.com");
     about.addCredit(i18n("Yuri Chornoivan"), i18n("Ukranian Data Files"), "");
     about.addCredit(i18n("Kristóf Kiszel"), i18n("Hungarian Data Files"), "ulysses@kubuntu.org");
+    about.addCredit(i18n("Souvik Das"), i18n("2-player mode"), "souvikdas728@gmail.com");
+    about.addCredit(i18n("Sayan Biswas"), i18n("Letters turned to clickable buttons"), "techsayan01@gmail.com");
 
     KAboutData::setApplicationData(about);
 
